@@ -5,7 +5,7 @@ use warnings;
 use 5.010;
 use parent qw/autobox/;
 
-our $VERSION = "1.017";
+our $VERSION = "1.018";
 
 =head1 NAME
 
@@ -62,6 +62,12 @@ autobox::Transform - Autobox methods to transform Arrays and Hashes
     $authors->map_by("books")->flat;
     # [ $book1, $book2, $book3 ]
 
+    # Return reference, even in list context, e.g. in a parameter list
+    report( genres => $books->map_by("genre")->to_ref );
+
+    # Return array, even in scalar context
+    @books->to_array;
+
 
 =head2 Hash Examples
 
@@ -83,6 +89,12 @@ autobox::Transform - Autobox methods to transform Arrays and Hashes
     $genre_count->map_each_to_array(sub { "$_: $_[0]" });
     # [ "1: Fantasy", "3: Sci-fi" ]
 
+    # Return reference, even in list context, e.g. in a parameter list
+    report( genre_count => $books->group_by_count("genre")->to_ref );
+
+    # Return hash, even in scalar context
+    $author->book_count->to_hash;
+
 
 =head2 Combined examples
 
@@ -293,16 +305,23 @@ context. E.g.
     $self->my_method(
         # Wrong, this is list context and wouldn't return an arrayref
         books => $books->grep_by("is_published"),
-    ),
+    );
 
     $self->my_method(
         # Correct, convert the list to an arrayref
         books => [ $books->grep_by("is_published") ],
-    ),
+    );
     $self->my_method(
         # Correct, ensure scalar context i.e. an array ref
         books => scalar $books->grep_by("is_published"),
-    ),
+    );
+
+    # Probably the nicest, since it goes at the end
+    $self->my_method(
+        # Correct, use ->to_ref to ensure an array reference is returned
+        books => $books->grep_by("is_published")->to_ref,
+    );
+
 
 
 =head1 AUTOBOX ARRAY METHODS
@@ -312,6 +331,8 @@ context. E.g.
 package # hide from PAUSE
     autobox::Transform::Array;
 
+use autobox::Core;
+
 
 
 sub __invoke_by {
@@ -674,7 +695,38 @@ sub flat {
     return wantarray ? @$result : $result;
 }
 
+=head2 @array->to_ref() : $arrayref
 
+Return the reference to the @array, regardless of context.
+
+Useful for ensuring the last array method return a reference while in
+scalar context. Typically:
+
+    do_stuff(
+        books => $author->map_by("books")->to_ref,
+    );
+
+map_by is called in list context, so without ->to_ref it would have
+return an array, not an arrayref.
+
+=cut
+
+sub to_ref {
+    my $array = shift;
+    return $array;
+}
+
+=head2 @array->to_array() : @array
+
+Return the @array, regardless of context. This is mostly useful if
+called on a ArrayRef at the end of a chain of method calls.
+
+=cut
+
+sub to_array {
+    my $array = shift;
+    return @$array;
+}
 
 
 
@@ -685,6 +737,9 @@ sub flat {
 package # hide from PAUSE
     autobox::Transform::Hash;
 
+use autobox::Core;
+
+
 
 sub key_value {
     my $hash = shift;
@@ -898,6 +953,36 @@ sub grep_each_defined {
 }
 
 
+=head2 %hash->to_ref() : $hashref
+
+Return the reference to the %hash, regardless of context.
+
+Useful for ensuring the last hash method return a reference while in
+scalar context. Typically:
+
+    do_stuff(
+        genre_count => $books->group_by_count("genre")->to_ref,
+    );
+
+=cut
+
+sub to_ref {
+    my $hash = shift;
+    return $hash;
+}
+
+=head2 %hash->to_hash() : %hash
+
+Return the %hash, regardless of context. This is mostly useful if
+called on a HashRef at the end of a chain of method calls.
+
+=cut
+
+sub to_hash {
+    my $hash = shift;
+    return %$hash;
+}
+
 
 
 =head1 DEVELOPMENT
